@@ -27,7 +27,7 @@ def csv_to_parquet(input_csv_path, output_parquet_path):
     spark = SparkSession.builder.appName(spark_app_name).getOrCreate()
 
     logging.warning("Load the csv dataset with header in {}".format(input_csv_path))
-    df = spark.read.option("header", "true").csv(input_csv_path)
+    df = spark.read.option("header", "true").option("inferSchema", "true").csv(input_csv_path)
 
     logging.warning("Save the output parquet in {}".format(output_parquet_path))
     df.write.parquet(output_parquet_path, mode="overwrite")
